==> haystack-trace-reader-1.0.7-sources.jar: com/expedia/www/haystack/trace/reader/config/entities/ElasticSearchConfiguration.scala <==
/*
 *  Copyright 2017 Expedia, Inc.
 *
 *     Licensed under the Apache License, Version 2.0 (the "License");
 *     you may not use this file except in compliance with the License.
 *     You may obtain a copy of the License at
 *
 *         http://www.apache.org/licenses/LICENSE-2.0
 *
 *     Unless required by applicable law or agreed to in writing, software
 *     distributed under the License is distributed on an "AS IS" BASIS,
 *     WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *     See the License for the specific language governing permissions and
 *     limitations under the License.
 *
 */
package com.expedia.www.haystack.trace.reader.config.entities

case class ElasticSearchClientConfiguration(endpoint: String,
                                            username: Option[String],
                                            password: Option[String],
                                            connectionTimeoutMillis: Int,
                                            readTimeoutMillis: Int)

case class SpansIndexConfiguration(indexNamePrefix: String,
                                   indexType: String,
                                   indexHourTtl: Int,
                                   indexHourBucket: Int,
                                   useRootDocumentStartTime: Boolean)

case class ServiceMetadataIndexConfiguration(enabled: Boolean,
                                             indexName: String,
                                             indexType: String)

case class ElasticSearchConfiguration(clientConfiguration: ElasticSearchClientConfiguration,
                                      spansIndexConfiguration: SpansIndexConfiguration,
                                      serviceMetadataIndexConfiguration: ServiceMetadataIndexConfiguration)

==> haystack-trace-reader-1.0.11-sources.jar: com/expedia/www/haystack/trace/reader/config/entities/ElasticSearchConfiguration.scala <==
/*
 *  Copyright 2019, Expedia Group.
 *
 *     Licensed under the Apache License, Version 2.0 (the "License");
 *     you may not use this file except in compliance with the License.
 *     You may obtain a copy of the License at
 *
 *         http://www.apache.org/licenses/LICENSE-2.0
 *
 *     Unless required by applicable law or agreed to in writing, software
 *     distributed under the License is distributed on an "AS IS" BASIS,
 *     WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *     See the License for the specific language governing permissions and
 *     limitations under the License.
 *
 */
package com.expedia.www.haystack.trace.reader.config.entities

import com.expedia.www.haystack.trace.commons.config.entities.AWSRequestSigningConfiguration

case class ElasticSearchClientConfiguration(endpoint: String,
                                            username: Option[String],
                                            password: Option[String],
                                            connectionTimeoutMillis: Int,
                                            readTimeoutMillis: Int)

case class SpansIndexConfiguration(indexNamePrefix: String,
                                   indexType: String,
                                   indexHourTtl: Int,
                                   indexHourBucket: Int,
                                   useRootDocumentStartTime: Boolean)

case class ServiceMetadataIndexConfiguration(enabled: Boolean,
                                             indexName: String,
                                             indexType: String)

case class ElasticSearchConfiguration(clientConfiguration: ElasticSearchClientConfiguration,
                                      spansIndexConfiguration: SpansIndexConfiguration,
                                      serviceMetadataIndexConfiguration: ServiceMetadataIndexConfiguration,
                                      awsRequestSigningConfiguration: AWSRequestSigningConfiguration)
